@@ -40,11 +40,14 @@ def add_counter_family(
         print(new_counter_family)
     """
     counter_family_input = AddCounterFamilyInput(name=name)
-    if (len(name) != 0):
+    if (name == ""):
+      print ("you cant leave the name parameter empty")
+    elif name!=str:
+      print ("the input must be a text, example name=''new name''")
+    else:
         result = addCounterFamily.execute(client, input=counter_family_input)
         return CounterFamily(name=result.name, id=result.id)
-    else:
-        print ("you cant leave the name parameter empty")
+
 
 def edit_counter_family(
     client: SymphonyClient,
